@@ -30,7 +30,10 @@
 
 import json
 import os
+import sys
 import requests
+import termios
+import tty
 
 # ----------------------------------------------------------------------
 # Support Package Developers
@@ -63,14 +66,14 @@ def load_key(path):
 
 # Either load key/endpoint from file or ask user and save to file.
 
-def get_key_endpoint(key_file, service="Cognitive Services"):
+def azkey(key_file, service="Cognitive Services"):
     """The user is asked for an Azure subscription key and endpoint. The
     provided information is saved into a file for future use. The
     contents of that file is the key and endpoint with the endpoint
     identified as starting with http:
 
     a14d1234abcda4f2f6e9f565df34ef24
-    https://westus2.api.cognitive.microsoft.com
+    https://westus2.api.cognitive.microsoft.com/
 
     """
 
@@ -163,7 +166,8 @@ def ask_password(prompt=None):
 
 # Send a request.
 
-def send_request(endpoint, url, subscription_key, request_data):
+
+def azrequest(endpoint, url, subscription_key, request_data):
     """Send anomaly detection request to the Anomaly Detector API. 
 
     If the request is successful, the JSON response is returned.
@@ -174,7 +178,7 @@ def send_request(endpoint, url, subscription_key, request_data):
     headers = {'Content-Type': 'application/json',
                'Ocp-Apim-Subscription-Key': subscription_key}
     
-    response = requests.post(endpoint+url,
+    response = requests.post(os.path.join(endpoint, url),
                              data=json.dumps(request_data),
                              headers=headers)
     
@@ -184,12 +188,14 @@ def send_request(endpoint, url, subscription_key, request_data):
         print(response.status_code)
         raise Exception(response.text)
 
-def ask_continue(begin=""):
-    print(begin + "Press Enter to continue: ", end="")
+def mlask(begin="", end=""):
+    print(begin + "Press Enter to continue: ", end=end)
     answer = input()
 
-def inform_about(title="", text="", delim="=", begin="", end="\n"):
+def mlcat(title="", text="", delim="=", begin="", end="\n"):
     sep = delim*len(title) + "\n" if len(title) > 0 else ""
     ttl_sep = "\n" if len(title) > 0 else ""
     print(begin + sep + title + ttl_sep + sep + ttl_sep + text, end=end)
 
+def mlpreview(fname, previewer="display"):
+    os.system(previewer + " " + fname)
